@@ -16,13 +16,16 @@ Install:
 https://pypi.python.org/pypi/kungfu
 pip install kungfu
 The above command will auto take care of the following requirements
-Requires pandas 0.12.0 (tested 0.12.0-2) which will also install numpy etc
-Requires openpyxl 1.5.8 (version 1.6.1 or higher, but lower than 2.0.0 may also work, but not tested)
-(pip install pandas==0.12.0; pip install openpyxl==1.5.8)
+Requires pandas 0.12.0 (tested 0.12.0-2) which will also install python-dateutil(dateutil), numpy, pytz, six
+Requires openpyxl for writing excel (tested with 1.5.8, version 1.6.1 or higher, but lower than 2.0.0 may also work.)
+xlrd for reading excel, xlwt for writing .xls (old format) file
+(pip install pandas==0.12.0; pip install openpyxl==1.5.8; pip install xlrd; pip install xlwt)
 
 
 Usage:
-Want pandas functions index?  http://pandas.pydata.org/pandas-docs/dev/genindex.html
+Want pandas functions index?
+http://pandas.pydata.org/pandas-docs/version/0.12.0/genindex.html
+http://pandas.pydata.org/pandas-docs/version/0.12.0/
 
 Call methods
 All the monkey-patched methods use UpperCase names; the original ones use lower_case names.
@@ -39,9 +42,11 @@ from pandas import isnull as isnull
 Frame.read = Frame.Read
 Frame.save = Frame.Save
 Frame.write = Frame.Save
-Frame.pprint = Frame.Print
+Frame.peek = Frame.Print
+Frame.Peek = Frame.Print
 Frame.play = Frame.Play
 Frame.sel = Frame.Sel
+Frame.selcol = Frame.SelCol
 Frame.selrow = Frame.SelRow
 Frame.delete = Frame.Del
 Frame.groupv = Frame.GroupV
@@ -60,7 +65,8 @@ Frame.maskout = Frame.Maskout
 # Frame.fillna = Frame.FillNA
 
 Series.play = Series.Play
-Series.pprint = Series.Print
+Series.peek = Series.Print
+Series.Peek = Series.Print
 Series.sel = Series.Sel
 Series.countval = Series.CountVal
 # Series.unique = Series.Uniques  --existing method
@@ -75,20 +81,26 @@ Series.maskout = Series.Maskout
 
 mergelr = MergeLR
 concatvh = ConcatVH
+Frame.tolist(), Frame.list()    <--homebrew method
+Series.tolist(), Series.list()   <--exisiting method in pandas
 
 # +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 # Frame IO, Frame info
 # +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-frame = Frame.Read(path, sep="\t", header=0)
+frame = Frame.Read(path, sep=",", header=0)
     Read data into a frame. This is a class method.
     Args:
         path, a text or csv file
-        sep, character used to separate the file
+        sep, character used to separate the file, e.g., '\t'
         header, the row number with header (0=first row, None=no header at all)
     Returns:
         a Frame object with the data.
     Raises:
         None
+        
+frame = Frame.Readx(path, sheetname='Sheet1', header=0)
+    Read xlsx, xls file into a frame
+    header, the row number with header (0=first row, None=no header at all)
 
 frame.Print([column=None])
     Print out common useful information of a frame.
@@ -468,6 +480,11 @@ for columnName, columnSeries in Frame.iteritems():
     columnUniques = columnSeries.Uniques()
 for rowIndex, rowSeries in Frame.iterrows():
 for index, value in Series.iteritems():
+
+Also consider apply, applymap, map
+apply works on a row / column basis of a DataFrame, 
+applymap works element-wise on a DataFrame, 
+and map works element-wise on a Series.    
 """
 
 
@@ -518,8 +535,9 @@ class PatchedFrame(Frame):
     __metaclass__ = monkeypatch_class
 
     @classmethod
-    def Read(cls, *args, **kwargs):
+    def Read(cls, path, sep=',', header=0, *args, **kwargs):
         """
+        (path, sep=',', header=0, *args, **kwargs)
         Read data into a frame. This is a class method.
         Args:
             path, a text or csv file
@@ -530,10 +548,27 @@ class PatchedFrame(Frame):
         Raises:
            None
         """
-        return pd.read_table(*args, **kwargs)
+        return pd.read_table(path, sep=sep, header=header, *args, **kwargs)
+    
+    @classmethod
+    def Readx(cls, path, sheetname='Sheet1', header=0, *args, **kwargs):
+        """
+        (path, sheetname='Sheet1', header=0, *args, **kwargs)
+        Read xlsx, xls file into a frame
+        Args:
+            path, a xlsx, xls file file
+            sep, character used to separate the file
+            header, the row number with header (0=first row, None=no header at all)
+        Returns:
+            a Frame object with the data
+        Raises:
+           None
+        """
+        return pd.read_excel(path, sheetname=sheetname, header=header, *args, **kwargs)
 
     def Save(self, outputFile, columns=None):
         """
+        (self, outputFile, columns=None)
         Save the content of a frame to an excel or csv file.
         Args:
             the path to the excel file (xlsx), or csv(.csv, comma separated); explicitly specify .xlsx or .csv 
@@ -553,6 +588,7 @@ class PatchedFrame(Frame):
 
     def Print(self, column=None):
         """
+        Print(self, column=None)
         Print out common useful information of a frame.
         Args:
             optional column name or index; if passed, print out information of only that column instead of that of whole frame.
@@ -594,7 +630,7 @@ class PatchedFrame(Frame):
             if type(column) in [str]:
                 columnName = column
                 columnIndex = frameColumns.index(columnName)
-            elif type(column) in [int]:
+            elif type(column) in [int,numpy.int32,numpy.int64]:
                 columnIndex = column
                 columnName = frameColumns[columnIndex]
             columnSeries = self.SelCol(column)
@@ -675,7 +711,7 @@ class PatchedFrame(Frame):
         def _PreProcessArgs(args):
             if len(args) == 1:
                 cols = args[0]
-                if type(cols) in [str,int]:
+                if type(cols) in [str,int,numpy.int32,numpy.int64]:
                     return ([cols],{})
                 elif type(cols) in [list]:
                     return (cols,{})
@@ -690,13 +726,13 @@ class PatchedFrame(Frame):
                 cols = args[0]
                 rows = args[1]
                 # cols
-                if type(cols) in [str,int]:
+                if type(cols) in [str,int,numpy.int32,numpy.int64]:
                     cols = [cols]
                 elif type(cols) in [list]:
                     cols = cols
 
                 # rows
-                if type(rows) in [str,int]:
+                if type(rows) in [str,int,numpy.int32,numpy.int64]:
                     rows = [rows]
                 elif type(rows) in [list]:
                     rows = rows
@@ -717,7 +753,7 @@ class PatchedFrame(Frame):
                 for col in cols:
                     if type(col) in [str]:
                         selectedCols.append(frm.loc[:,col])
-                    elif type(col) in [int]:
+                    elif type(col) in [int,numpy.int32,numpy.int64]:
                         selectedCols.append(frm.iloc[:,col])
                 selectedCols = pd.concat(selectedCols, join='outer', axis=1)
             else:
@@ -736,7 +772,7 @@ class PatchedFrame(Frame):
                     for row in rows:
                         if type(row) in [str]:
                             selectedRows.append(selectedCols.loc[[row],:])
-                        elif type(row) in [int]:
+                        elif type(row) in [int,numpy.int32,numpy.int64]:
                             selectedRows.append(selectedCols.iloc[[row],:])
                 else:
                     selectedRows = [selectedCols]
@@ -756,6 +792,7 @@ class PatchedFrame(Frame):
 
     def SelCol(self, column):
         """
+        (self, column)
         Select a single column from frame.
         Args:
             a int representing column index or a string representing column name
@@ -768,6 +805,7 @@ class PatchedFrame(Frame):
 
     def SelRow(self, row):
         """
+        (self, row)
         Select a single row from frame.
         Args:
             a int representing row index or a string representing row name
@@ -798,6 +836,7 @@ class PatchedFrame(Frame):
 
     def GroupV(self, edgeMatchSeries, groupColumnName='AutoGroup'):
         """
+        (self, edgeMatchSeries, groupColumnName='AutoGroup')
         Edge condition based grouping along the vertical direction.
         1) Create a new column and put the group category of each block into this column, such as "G0","G1","G2"
         2) Edge is marked as "Edge"
@@ -816,6 +855,7 @@ class PatchedFrame(Frame):
 
     def SplitH(self, subFrameSize=1, resetIndex=True):
         """
+        (self, subFrameSize=1, resetIndex=True)
         Split frame along the horizontal direction into pieces of equal size if possible.
         Args:
             subFrameSize means how many cols each subFrame would have
@@ -848,6 +888,7 @@ class PatchedFrame(Frame):
 
     def ReorderCols(self, columns=[]):
         """
+        (self, columns=[])
         Reorder columns of a frame.
         Args:
              a list that has equal size to the original columns
@@ -861,6 +902,7 @@ class PatchedFrame(Frame):
 
     def ReorderRows(self, indices=[]):
         """
+        (self, indices=[])
         Reorder the rows of a frame.
         Args:
             a list that has equal size to the original indices
@@ -874,6 +916,7 @@ class PatchedFrame(Frame):
 
     def RenameCols(self, newColumns=[]):
         """
+        (self, newColumns=[])
         Rename the names of each column of a frame.
         Args:
             a list that has equal size to the original columns
@@ -889,6 +932,7 @@ class PatchedFrame(Frame):
 
     def NewCol(self, newColumnName="NewColumn", newColumnValue=NA):
         """
+        (self, newColumnName="NewColumn", newColumnValue=NA)
         Append a new column to the frame.
         Args:
             new column name in string
@@ -905,7 +949,10 @@ class PatchedFrame(Frame):
         return self
 
     def FindVal(self, valToFind, *args):
-        """Print out all columns containing valToFind; only allows a single value to be passed each time"""
+        """
+        (self, valToFind, *args)
+        Print out all columns containing valToFind; only allows a single value to be passed each time
+        """
         assert len(args) == 0, "Only one value should be passed at a time."
         for colName, colSeries in self.iteritems():
             if valToFind in colSeries.unique():
@@ -915,7 +962,10 @@ class PatchedFrame(Frame):
                 print "+++++++++++++++++++++++++++++++++++++++++"
 
     def CountVal(self, valToCount, *args):
-        """Count all occurrence of the valToCount within the frame, can count np.nan, only allows a single value to be passed each time"""
+        """
+        (self, valToCount, *args)
+        Count all occurrence of the valToCount within the frame, can count np.nan, only allows a single value to be passed each time
+        """
         assert len(args) == 0, "Only one value should be passed at a time."
         # np.where reports error if valToCount is a string
         # return np.where(self == valToCount, 1, 0).sum()
@@ -937,7 +987,7 @@ class PatchedFrame(Frame):
             result = []
         else:
             # when column does not have a name, it uses a numpy.int64 as its name. Then convert to python int.
-            if type(self.columns[0]) in [numpy.int64]:
+            if type(self.columns[0]) in [numpy.int32,numpy.int64]:
                 result = [int(column) for column in self.columns]
             else:
                 result = list(self.columns)
@@ -948,7 +998,7 @@ class PatchedFrame(Frame):
         if len(self.index) == 0:
             result = []
         else:
-            if type(self.index[0]) in [numpy.int64]:
+            if type(self.index[0]) in [numpy.int32,numpy.int64]:
                 result = [int(i) for i in self.index]
             else:
                 result = list(self.index)
@@ -986,8 +1036,13 @@ class PatchedFrame(Frame):
         """
         return self.convert_objects(convert_dates=True, convert_numeric=True, copy=True)
 
+    def ToList(self):
+        """returns a list representation of a frame"""
+        return self.values.tolist()
+        
     def Maskout(self, condition):
         """
+        (self, condition)
         1) if a frame cell's value matches the condition, then masked as NA; if not, preserve the original value
         2) returned as a copy; the original frame remains unchanged
         3) condition could be:
@@ -1055,7 +1110,7 @@ class PatchedFrame(Frame):
             """
             # modification begins
             # convert a single str or int to a list
-            if type(values) in [str,int]: values = [values]
+            if type(values) in [str,int,numpy.int32,numpy.int64]: values = [values]
             # modification ends
             if isinstance(values, dict):
                 from collections import defaultdict
@@ -1092,7 +1147,7 @@ class PatchedFrame(Frame):
                                  frm.columns)
 
         # preprocess
-        if type(condition) in [int,str]:
+        if type(condition) in [int,numpy.int32,numpy.int64,str]:
             condition = [condition]
         # if a list (including list converted from the int and str above) or a dict
         # pass directly to the _FrameIsIn() which will return a frame of the same shape with values of True/False
@@ -1147,6 +1202,7 @@ class PatchedSeries(Series):
 
     def Print(self):
         """
+        (self)
         Print out useful information of a series.
         Args:
             None
@@ -1180,6 +1236,7 @@ class PatchedSeries(Series):
 
     def Sel(self, elements=[]):
         """
+        (self, elements=[])
         Select elements from a series.
         Args:
             choose one of the three options:
@@ -1192,7 +1249,7 @@ class PatchedSeries(Series):
            None
         """
         # preprocess
-        if type(elements) in [str,int]:
+        if type(elements) in [str,int,numpy.int32,numpy.int64]:
             elements = [elements]
 
         # process
@@ -1200,14 +1257,17 @@ class PatchedSeries(Series):
         for i in elements:
             if type(i) in [str]:
                 selected.append(self.loc[i])
-            elif type(i) in [int]:
+            elif type(i) in [int,numpy.int32,numpy.int64]:
                 selected.append(self.iloc[i])
 
         # if only one selected, do not return a list
         return selected[0] if len(selected) == 1 else selected
 
     def CountVal(self, valToCount):
-        """count all occurrence, can count np.nan as well"""
+        """
+        (self, valToCount)
+        count all occurrence, can count np.nan as well
+        """
         if pd.isnull(valToCount):
             return self.isnull().sum()
         else:
@@ -1230,7 +1290,7 @@ class PatchedSeries(Series):
         if len(self.index) == 0:
             result = []
         else:
-            if type(self.index[0]) in [numpy.int64]:
+            if type(self.index[0]) in [numpy.int32,numpy.int64]:
                 result = [int(i) for i in self.index]
             else:
                 result = list(self.index)
@@ -1276,7 +1336,10 @@ class PatchedSeries(Series):
         return self.str
 
     def Maskout(self, condition):
-        """internally use the Frame.Maskout(); so condition is of the same type"""
+        """
+        (self, condition)
+        internally use the Frame.Maskout(); so condition is of the same type
+        """
         theSeries = self
         theSeriesFrame = Frame(theSeries)
         theSeriesFrameMasked = theSeriesFrame.Maskout(condition)
@@ -1292,6 +1355,7 @@ class PatchedSeries(Series):
 
 def MergeLR(left, right, join='union', onKeys=[], sort=True):
     """
+    (left, right, join='union', onKeys=[], sort=True)
     Merge 2 frames in the horizontal direction.
     Args:
         left frame, right frame
@@ -1346,6 +1410,7 @@ def MergeLR(left, right, join='union', onKeys=[], sort=True):
 
 def ConcatVH(frameList, axis=0, join="union", sort=False):
     """
+    (frameList, axis=0, join="union", sort=False)
     Concat in the vertical or horizontal direction.
     When concat in the vertical direction, i.e. along index, the horizontal (i.e. along columns) is defined as join direction.
     When concat in the horizontal columns direction, the join direction is the vertical index direction.
@@ -1433,11 +1498,14 @@ def ConcatVH(frameList, axis=0, join="union", sort=False):
 from pandas import isnull as isna
 from pandas import isnull as isnull
 Frame.read = Frame.Read
+Frame.readx = Frame.Readx
 Frame.save = Frame.Save
 Frame.write = Frame.Save
-Frame.pprint = Frame.Print
+Frame.peek = Frame.Print
+Frame.Peek = Frame.Print
 Frame.play = Frame.Play
 Frame.sel = Frame.Sel
+Frame.selcol = Frame.SelCol
 Frame.selrow = Frame.SelRow
 Frame.delete = Frame.Del
 Frame.groupv = Frame.GroupV
@@ -1452,11 +1520,14 @@ Frame.cnames = Frame.Columns
 Frame.names = Frame.Columns
 Frame.rnames = Frame.Indices
 Frame.num = Frame.ToNum
+Frame.tolist = Frame.ToList
+Frame.list = Frame.ToList
 Frame.maskout = Frame.Maskout
 # Frame.fillna = Frame.FillNA
 
 Series.play = Series.Play
-Series.pprint = Series.Print
+Series.peek = Series.Print
+Series.Peek = Series.Print
 Series.sel = Series.Sel
 Series.countval = Series.CountVal
 # Series.unique = Series.Uniques  --existing method
@@ -1467,6 +1538,8 @@ Series.cames = Series.Indices
 Series.num = Series.ToNum
 Series.str = Series.ToStr
 Series.maskout = Series.Maskout
+Series.ToList = Series.tolist
+Series.list = Series.tolist
 # Series.fillna = Series.FillNA
 
 mergelr = MergeLR
